/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.vew.sim.sim.steuerung;

import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Modelliert einen Thread, dessen Ausführung in Abhängigkeit
 * von einem oder mehreren Vorgänger-Threads erfolgen kann
 *
 * @version $Revision: 1.2 $ / $Date: 2008/10/31 13:30:30 $ / ($Author: Sans $)
 *
 * @author Dambach-Werke GmbH
 * @author Stefan Sans
 */
class WarteThread extends Thread

{

  private final static Debug _debug = Debug.getLogger();

  /**
   * Erzeugt einen neuen Warte-Thread
   *
   */
  public WarteThread()
  {
    super();
    _result = true;
  }

  /**
   * Das Ergebnis der Ausführung dieses Threads
   */
  private boolean _result;

  /**
   * Bestimmt das Ergebnis der Ausführung dieses Threads
   * @return das Ergebnis der Ausführung dieses Threads
   */
  public boolean getResult()
  {
    return _result;
  }

  /**
   * Setzt das Ergebnis der Ausführung dieses Threads
   * @param result das Ergebnis der Ausführung dieses Threads
   */
  void setResult(boolean result)
  {
    _result = result;
  }

  /**
   * Startet diesen Wartethread. Der Thread startet nur, wenn alle
   * Vorgänger-Threads beendet sind und ein positives Ergebnis
   * geliefert haben
   * @param vorgaenger Feld der Vorgänger-Warte-Threads
   * - wenn dieses Feld leer ist, startet diese Instanz sofort
   */
  public void start(WarteThread[] vorgaenger) 
  {
    for(Thread thread: vorgaenger)
    {
      try
      {
        thread.join();
      }  
      catch(InterruptedException e)
      {
        _debug.error("Workflow wurde abgebrochen");
      }
    }  
    
    for(WarteThread thread: vorgaenger)
    {
      if (!thread.getResult())
      {
        setResult(false);
        break;
      }  
    }  

    if (_result)
    {
      super.start();  
    }
  }

  /* (non-Javadoc)
   * @see java.lang.Thread#run()
   */
  public void run() 
  {
    // Default Implementierung: Tue nichts
  }
   
}
